# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gym_anm',
 'gym_anm.agents',
 'gym_anm.envs',
 'gym_anm.envs.anm6_env',
 'gym_anm.envs.anm6_env.rendering',
 'gym_anm.envs.anm6_env.rendering.py',
 'gym_anm.simulator',
 'gym_anm.simulator.components']

package_data = \
{'': ['*'], 'gym_anm.envs.anm6_env.rendering': ['css/*', 'envs/anm6/*', 'js/*']}

install_requires = \
['cvxpy>=1.2.2,<2.0.0',
 'gym>=0.21,<0.22',
 'numpy>=1.23.5,<2.0.0',
 'pandas>=1.5.2,<2.0.0',
 'requests>=2.28.1,<3.0.0',
 'websocket-client==0.56.0',
 'websocket-server==0.4']

setup_kwargs = {
    'name': 'gym-anm',
    'version': '1.1.3',
    'description': 'A framework to build Reinforcement Learning environments for Active Network Management tasks in electricity networks.',
    'long_description': "# Gym-ANM\n[![Downloads](https://pepy.tech/badge/gym-anm)](https://pepy.tech/project/gym-anm)\n[![Documentation Status](https://readthedocs.org/projects/ansicolortags/badge/?version=latest)](https://gym-anm.readthedocs.io/en/latest/)\n[![codecov](https://codecov.io/gh/robinhenry/gym-anm/branch/master/graph/badge.svg?token=7JSMJPPIQ7)](https://codecov.io/gh/robinhenry/gym-anm)\n[![Checks](https://github.com/robinhenry/gym-anm/actions/workflows/ci_checks.yml/badge.svg)](https://github.com/robinhenry/gym-anm/actions/workflows/ci_checks.yml)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\n`gym-anm` is a framework for designing reinforcement learning (RL) environments that model Active Network\nManagement (ANM) tasks in electricity distribution networks. It is built on top of the\n[OpenAI Gym](https://github.com/openai/gym) toolkit.\n\nThe `gym-anm` framework was designed with one goal in mind: **bridge the gap between research in RL and in\nthe management of power systems**. We attempt to do this by providing RL researchers with an easy-to-work-with\nlibrary of environments that model decision-making tasks in power grids.\n\n**Papers:**\n*  [Gym-ANM: Reinforcement Learning Environments for Active Network Management Tasks in Electricity Distribution Systems](https://doi.org/10.1016/j.egyai.2021.100092)\n*  [Gym-ANM: Open-source software to leverage reinforcement learning for power system management in research and education](https://doi.org/10.1016/j.simpa.2021.100092)\n\n## Key features\n*  Very little background in electricity systems modelling it required. This makes `gym-anm` an ideal starting point\n   for RL students and researchers looking to enter the field.\n*  The environments (tasks) generated by `gym-anm` follow the [OpenAI Gym](https://github.com/openai/gym)\n   framework, with which a large part of the RL community is already familiar.\n*  The flexibility of `gym-anm`, with its different customizable components, makes it a suitable framework\n   to model a wide range of ANM tasks, from simple ones that can be used for educational purposes, to complex ones\n   designed to conduct advanced research.\n\n## Documentation\nDocumentation is provided online at [https://gym-anm.readthedocs.io/en/latest/](https://gym-anm.readthedocs.io/en/latest/).\n\n## Installation\n\n### Requirements\n`gym-anm` requires Python 3.8+ and can run on Linux, MaxOS, and Windows. Some rendering features may not work properly\non Windows (not tested).\n\nWe recommend installing `gym-anm` in a Python environment (e.g., [virtualenv](https://virtualenv.pypa.io/en/latest/)\nor [conda](https://conda.io/en/latest/#)).\n\n### Using pip\nUsing pip (preferably after activating your virtual environment):\n```\npip install gym-anm\n```\n\n### Building from source\nAlternatively, you can build `gym-anm` directly from source:\n```\ngit clone https://github.com/robinhenry/gym-anm.git\ncd gym-anm\npip install -e .\n```\n\n## Example\nThe following code snippet illustrates how `gym-anm` environments can be used. In this example,\nactions are randomly sampled from the action space of the environment `ANM6Easy-v0`. For more information\nabout the agent-environment interface, see the official [OpenAI Gym documentation](https://github.com/openai/gym).\n```\nimport gym\nimport time\n\ndef run():\n   env = gym.make('gym_anm:ANM6Easy-v0')\n   o = env.reset()\n\n   for i in range(100):\n       a = env.action_space.sample()\n       o, r, done, info = env.step(a)\n       env.render()\n       time.sleep(0.5)  # otherwise the rendering is too fast for the human eye.\n\n   env.close()\n\nif __name__ == '__main__':\n    run()\n```\nThe above code would render the environment in your default web browser as shown in the image below:\n![alt text](https://github.com/robinhenry/gym-anm/blob/master/docs/source/images/anm6-easy-example.png?raw=true)\n\nAdditional example scripts can be found in [examples/](examples).\n\n## Testing the installation\nAll unit tests in `gym-anm` can be ran from the project root directory with:\n```\npython -m pytest tests\n```\n\n## Contributing\nContributions are always welcome! Please read the [contribution guidelines](CONTRIBUTING.md) first.\n\n## Citing the project\nAll publications derived from the use of `gym-anm` should cite the following two 2021 papers:\n```\n@article{HENRY2021100092,\n    title = {Gym-ANM: Reinforcement learning environments for active network management tasks in electricity distribution systems},\n    journal = {Energy and AI},\n    volume = {5},\n    pages = {100092},\n    year = {2021},\n    issn = {2666-5468},\n    doi = {https://doi.org/10.1016/j.egyai.2021.100092},\n    author = {Robin Henry and Damien Ernst},\n}\n```\n```\n@article{HENRY2021100092,\n    title = {Gym-ANM: Open-source software to leverage reinforcement learning for power system management in research and education},\n    journal = {Software Impacts},\n    volume = {9},\n    pages = {100092},\n    year = {2021},\n    issn = {2665-9638},\n    doi = {https://doi.org/10.1016/j.simpa.2021.100092},\n    author = {Robin Henry and Damien Ernst}\n}\n```\n\n## Maintainers\n`gym-anm` is currently maintained by [Robin Henry](https://www.robinxhenry.com/).\n\n## License\nThis project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.\n",
    'author': 'Robin Henry',
    'author_email': 'robin@robinxhenry.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/robinhenry/gym-anm',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
